@@ -302,6 +302,7 @@ warn "Monad law, left identity" = f =<< return a ==> f a where _ = noQuickCheck
 warn "Monad law, right identity" = m >>= return ==> m where _ = noQuickCheck
 warn "Monad law, right identity" = return =<< m ==> m where _ = noQuickCheck
 warn = liftM ==> fmap
+warn = liftA ==> fmap
 hint = m >>= return . f ==> fmap f m where _ = noQuickCheck -- cannot be fmap, because is in Functor not Monad
 hint = return . f =<< m ==> fmap f m where _ = noQuickCheck
 warn = (if x then y else return ()) ==> Control.Monad.when x $ _noParen_ y where _ = not (isAtom y) && noQuickCheck
@@ -465,6 +466,16 @@ hint = throw (ErrorCall a) ==> error a
 warn = toException NonTermination ==> nonTermination
 warn = toException NestedAtomically ==> nestedAtomically
 
+-- STOREABLE/PTR
+
+hint = castPtr nullPtr ==> nullPtr
+hint = castPtr (castPtr x) ==> castPtr x
+hint = plusPtr (castPtr x) ==> plusPtr x
+hint = minusPtr (castPtr x) ==> minusPtr x
+hint = minusPtr x (castPtr y) ==> minusPtr x y
+hint = peekByteOff (castPtr x) ==> peekByteOff x
+hint = pokeByteOff (castPtr x) ==> pokeByteOff x
+
 -- WEAK POINTERS
 
 warn = mkWeak a a b ==> mkWeakPtr a b
@@ -708,6 +719,7 @@ foo = (\a -> Foo {..}) 1
 foo = zipWith SymInfo [0 ..] (repeat ty) -- map (\ x -> SymInfo x ty) [0 ..]
 f rec = rec
 mean x = fst $ foldl (\(m, n) x' -> (m+(x'-m)/(n+1),n+1)) (0,0) x
+{-# LANGUAGE TypeApplications #-} \
 foo = id @Int
 foo = id 12 -- 12
 
